# Generated by Django 4.0 on 2021-12-24 00:19

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('developmentEmailDashboard', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='developmentemail',
            name='email_type',
            field=models.CharField(default='text/plain', max_length=20),
            preserve_default=False,
        ),
    ]
