# from django.contrib import admin
# from .models import DevelopmentEmail,Inbox,InboxEmail
# # Register your models here.
# admin.site.register(DevelopmentEmail)
# admin.site.register(Inbox)
# admin.site.register(InboxEmail)