# Generated by Django 4.0 on 2021-12-22 22:48

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='DevelopmentEmail',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('subject', models.CharField(max_length=200)),
                ('body', models.TextField()),
                ('from_email', models.EmailField(max_length=254)),
                ('extra_headers', models.JSONField()),
                ('to', models.JSONField()),
                ('bcc', models.JSONField()),
                ('cc', models.JSONField()),
                ('reply_to', models.JSONField()),
                ('created', models.DateTimeField(auto_now_add=True)),
            ],
            options={
                'ordering': ['-created'],
            },
        ),
        migrations.CreateModel(
            name='Inbox',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('email', models.EmailField(max_length=254, unique=True)),
                ('created', models.DateTimeField(auto_now_add=True)),
            ],
            options={
                'ordering': ['-created'],
            },
        ),
        migrations.CreateModel(
            name='InboxEmail',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('read', models.BooleanField(default=False)),
                ('is_sender', models.BooleanField(default=False)),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('email', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='developmentEmailDashboard.developmentemail')),
                ('inbox', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='developmentEmailDashboard.inbox')),
            ],
            options={
                'ordering': ['-created'],
            },
        ),
    ]
